@@ -1,11 +1,12 @@
-# Copyrights 1999,2001-2007 by Mark Overmeer.
+# Copyrights 1999,2001-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.00.
+# Pod stripped from pm file by OODoc 1.04.
 
 package MIME::Types;
 use vars '$VERSION';
-$VERSION = '1.20';
+$VERSION = '1.24';
+
 
 use strict;
 
@@ -13,9 +14,6 @@ use MIME::Type ();
 use Carp;
 
 
-#-------------------------------------------
-
-
 my %list;
 sub new(@) { (bless {}, shift)->init( {@_} ) }
 
@@ -417,7 +415,7 @@ application/vnd.kde.kspread	ksp
 application/vnd.kde.kword	kwd,kwt
 application/vnd.kenameapp	htke
 application/vnd.kidspiration	kia
-application/vnd.Kinar		kne,knp,sdf
+application/vnd.Kinar		kne,knp
 application/vnd.google-earth.kml+xml			kml	8bit
 application/vnd.google-earth.kmz			kmz	8bit
 application/vnd.koan
@@ -480,7 +478,22 @@ application/vnd.nokia.radio-presets	rpss
 application/vnd.novadigm.EDM
 application/vnd.novadigm.EDX
 application/vnd.novadigm.EXT
+application/vnd.oasis.opendocument.text			odt
+application/vnd.oasis.opendocument.text-template	ott
+application/vnd.oasis.opendocument.text-web		oth
+application/vnd.oasis.opendocument.text-master		odm
+application/vnd.oasis.opendocument.graphics		odg
+application/vnd.oasis.opendocument.graphics-template	otg
+application/vnd.oasis.opendocument.presentation		odp
+application/vnd.oasis.opendocument.presentation-template	otp
+application/vnd.oasis.opendocument.spreadsheet		ods
+application/vnd.oasis.opendocument.spreadsheet-template	ots
+application/vnd.oasis.opendocument.chart		odc
+application/vnd.oasis.opendocument.formula		odf
+application/vnd.oasis.opendocument.database		odb
+application/vnd.oasis.opendocument.image		odi
 application/vnd.obn
+application/vnd.openxmlformats-officedocument.spreadsheetml.sheet xlsx quoted-printable
 application/vnd.osa.netdeploy
 application/vnd.palm		prc,pdb,pqa,oprc
 application/vnd.paos.xml
@@ -519,6 +532,13 @@ application/vnd.smaf			mmf
 application/vnd.sss-cod
 application/vnd.sss-dtf
 application/vnd.sss-ntf
+application/vnd.stardivision.chart	sds
+application/vnd.stardivision.calc	sdc
+application/vnd.stardivision.writer	sdw
+application/vnd.stardivision.writer-global	sgl
+application/vnd.stardivision.draw	sda
+application/vnd.stardivision.impress	sdd
+application/vnd.stardivision.math	sdf
 application/vnd.street-stream
 application/vnd.sun.xml.calc		sxc
 application/vnd.sun.xml.calc.template	stc
@@ -628,7 +648,7 @@ application/x-mac-compactpro	cpt
 application/x-maker		frm,maker,frame,fm,fb,book,fbdoc
 application/x-mathcad	# mcd, but there is also vnd.mcd
 application/x-mif		mif
-application/xml			xml xsl				8bit
+application/xml			xml,xsl				8bit
 application/xml-dtd		dtd				8bit
 application/xml-external-parsed-entity
 application/x-msaccess			mda,mdb,mde,mdf		base64
@@ -754,7 +774,7 @@ image/cgm
 image/g3fax
 image/gif			gif				base64
 image/ief			ief				base64
-image/jp2			jp2,jpg2
+image/jp2			jp2,jpg2			base64
 image/jpeg			jpeg,jpg,jpe			base64
 image/jpm			jpm,jpgm
 image/jpx			jpf,jpx
@@ -805,7 +825,7 @@ message/external-body							8bit
 message/http
 message/news								8bit
 message/partial								8bit
-message/rfc822								8bit
+message/rfc822				eml				8bit
 message/s-http
 message/sip
 message/sipfrag
@@ -841,7 +861,8 @@ multipart/x-ustar
 multipart/x-www-form-urlencoded
 multipart/x-zip
 text/calendar
-text/comma-separated-values		csv				8bit
+text/csv				csv				8bit
+text/comma-separated-values						8bit
 text/css				css				8bit
 text/directory
 text/enriched
@@ -936,6 +957,9 @@ x-world/x-vrml				wrl,vrml
 vms:text/plain				doc				8bit
 mac:application/x-macbase64		bin
 
+# IE6 bug
+image/pjpeg								base64
+
 __MIMETYPES__
 
 1;
